@@ -50,6 +50,24 @@
 ##' @param spline_linear is the number of spline terms needed to estimate the linear term.
 ##' @param spline_quad is the number of spline terms needed to estimate the quadratic term.
 ##'
+##' @details
+##'
+##'   This estimator bears a strong
+##'   resemblance to general regression estimators in the survey
+##'   literature, part of a more general class of calibration
+##'   estimators (Deville and Sarndal, 1992). It is
+##'   doubly robust, which means that it is consistent if
+##'   either of the models is true (Scharfstein, Rotnitzky and Robins
+##'   1999).  If the Y-model is correct, then the first term in
+##'   the previous equation is unbiased for \eqn{\xi} and the second term has mean
+##'   zero even if the T-model is wrong. If the Y-model is incorrect, the
+##'   first term is biased, but the second term gives a consistent estimate
+##'   of (minus one times) the bias from the Y-model if the T-model is
+##'   correct.
+##'
+##' This function is a doubly-robust estimator that fits an outcome regression
+##' model with a bias correction term.  For details see Schafer and Galagate (2015).
+##'
 ##' @return \code{aipwee_est}  returns an object of class "causaldrf_lsfit",
 ##' a list that contains the following components:
 ##' \item{param}{parameter estimates for a add_spl fit.}
@@ -68,6 +86,22 @@
 ##' continuous treatment and outcome: alternative estimators for parametric
 ##' dose-response models. \emph{Manuscript in preparation}.
 ##'
+##' Schafer, Joseph L, Kang, Joseph (2008).  Average causal effects from
+##' nonrandomized studies: a practical guide and simulated example.
+##' \emph{Psychological methods}, \bold{13.4}, 279.
+##'
+##' Robins, James M and Rotnitzky, Andrea (1995).
+##' Semiparametric efficiency in multivariate regression models with missing data
+##' \emph{Journal of the American Statistical Association}, \bold{90.429}, 122--129.
+##'
+##' Scharfstein, Daniel O and Rotnitzky, Andrea and Robins, James M (1999).
+##' Adjusting for nonignorable drop-out using semiparametric nonresponse models
+##' \emph{Journal of the American Statistical Association}, \bold{94.448}, 1096--1120.
+##'
+##' Deville, Jean-Claude and Sarndal, Carl-Erik (1992).
+##' Calibration estimators in survey sampling
+##' \emph{Journal of the American Statistical Association}, \bold{87.418}, 376--380.
+##'
 ##' @examples
 ##'
 ##' ## Example from Schafer (2015).
@@ -331,8 +365,8 @@ aipwee_est <- function(Y,
 
 
     theta_0_est_reg <- mean(as.matrix(theta_0_covars) %*% coef_0_reg )
-    theta_1_est_reg <- mean(as.matrix(theta_1_covars) %*% coef_1_reg / tempdat$treat)
-    theta_2_est_reg <- mean(as.matrix(theta_2_covars) %*% coef_2_reg / tempdat$treat^2 )
+    theta_1_est_reg <- mean( (as.matrix(theta_1_covars) %*% coef_1_reg / tempdat$treat)[which(tempdat$treat != 0)] )
+    theta_2_est_reg <- mean( (as.matrix(theta_2_covars) %*% coef_2_reg / tempdat$treat^2 )[which(tempdat$treat != 0)] )
 
     reg_coefs <- c(theta_0_est_reg,
                    theta_1_est_reg,
@@ -404,7 +438,7 @@ aipwee_est <- function(Y,
     theta_1_covars <- basis_mat[,  c( (n_covars + 1):(n_covars + n_covars_lin) )   ]
 
     theta_0_est_reg <- mean(as.matrix(theta_0_covars) %*% coef_0_reg )
-    theta_1_est_reg <- mean(as.matrix(theta_1_covars) %*% coef_1_reg / tempdat$treat )
+    theta_1_est_reg <- mean( (as.matrix(theta_1_covars) %*% coef_1_reg / tempdat$treat )[which(tempdat$treat != 0)] )
 
     reg_coefs <- c(theta_0_est_reg,
                    theta_1_est_reg)
